==> haskell-http-types-0.12.3-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.12.3
id: http-types-0.12.3-D3aEnVjdeLuS27pc1eWXD
key: http-types-0.12.3-D3aEnVjdeLuS27pc1eWXD
license: BSD-3-Clause
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
author: Aristid Breitkreuz, Michael Snoyman
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
abi: 0d048b2efdbc75309b8925ac42363fb8
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
import-dirs: /usr/lib/ghc-8.6.4/site-local/http-types-0.12.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/http-types-0.12.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/http-types-0.12.3
hs-libraries: HShttp-types-0.12.3-D3aEnVjdeLuS27pc1eWXD
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.12.3-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.12.3
id: http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
key: http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
license: BSD-3-Clause
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
author: Aristid Breitkreuz, Michael Snoyman
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
abi: 8aebc5f1259404294fba20ebfced0bc2
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-types-0.12.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-types-0.12.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-types-0.12.3
hs-libraries: HShttp-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
